@@ -2,7 +2,6 @@ import subprocess
 import re
 import os 
 import sys
-import html2text 
 import logging
 import collections
 from pyblog.colored_print import printDebug
@@ -17,11 +16,11 @@ try:
             , stdin=subprocess.PIPE
             )
 except OSError:
-    logging.debug("Pandoc not found")
+    printDebug("INFO", "Pandoc not found")
     panDoc = False
     
 if not panDoc:
-    import text.html2text as html2text
+    import html2text as html2text
     import markdown 
 
 def decodeText(text):
